# Chapter 1

## Notes on use with the CodeChat System
All configuration files were generated using the command `mdbook init mdbook`. The CodeChat project configuration file, `codechat_config.yaml`, has a `source_path` setting of `src` and an `output_path` setting of `book`to match the standard mdbook configuration.

As demonstrated in the following chapters of this book, [CodeChat](https://codechat.readthedocs.io/en/master/)'s [preprocessor for mdbook](https://codechat.readthedocs.io/en/master/CodeChat/mdbook_CodeChat.py.html) allows authors to include source code in the book; comments in the source code are interpreted as Markdown.

To use these files, simply copy them to a new project directory of your choice. Open them in your preferred text editor/IDE, then use a appropriate CodeChat extension/plugin to open any of these files to build and view the results.
